package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````*1``````````0```````
M`+&0``````!``#@`"0!``!L`&@````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*DP````````J3``
M```````0``````$````&````````JX@```````"[B````````+N(````````
M!0`````````%*````````!```````@````8```````"KF````````+N8````
M````NY@````````",`````````(P``````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````H>````````"AX````````*'@`````````00````````!!```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*N(````````NX@`````
M``"[B`````````1X````````!'@``````````2]L:6(O;&0V-"YS;RXQ````
M```$````%`````-'3E4`0%/P(Q*6W;Q7;ZG0MUH6"#U[&((````$````$```
M``%'3E4```````````,````"````````````````````0P````````!A````
M``````````````````````````!;`````````!@`````````,@`````````S
M````````````````````4P```````````````````"X`````````5@``````
M``!``````````"P`````````60````````!%````````````````````00``
M````````````````````````````/```````````````````````````````
M.P`````````<`````````%$````````````````````U`````````!L`````
M````1P````````!2```````````````````````````````(````````````
M````````+0`````````B`````````"D```````````````````!0````````
M`$\```````````````````!#````````````````````0@````````!>````
M``````X`````````)P`````````%````````````````````3``````````^
M``````````<```````````````````!=`````````#\`````````'P``````
M``!$````````````````````2P````````!7`````````!T`````````.@``
M```````/`````````$8`````````,0`````````P`````````$@`````````
M````````````````````````````````7```````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!8````````````````````````````````````````
M``(````````````````````-`````````!$````````````````````&````
M`````$X```````````````````!)`````````!<`````````7P``````````
M```````````````````````````````>````````````````````````````
M```3`````````!``````````"0`````````*````````````````````````
M```````2````````````````````*```````````````````````````````
M50`````````J``````````L````````````````````D``````````P`````
M```````````````O`````````%0`````````(0````````!:`````````"L`
M````````%``````````Y`````````$T````````````````````W````````
M````````````)@`````````9`````````!8`````````-@`````````C````
M`````````````````````````````````````#0`````````8```````````
M````````````````````)0```````````````````````````````P``````
M```5````````````````````&@```````````````````#T`````````````
M``````!*`````````"``````````.```````````````````````````````
M````````````````````````````````````````````````````````````
M````!````!$```!&````!`````B$!$`%`!`0((0`AH`$``(H"`0@"0``"8((
M`@"Z11"@B`````````!&````20```$P```!-````5````%4```!6````6```
M`%D```!;````7````%T```!>````8```````````']_%;BU'WLY\FG]KMIO%
M+GS49-0.Y/\A'%AQV0'&1^)OBP&RP.-+K(?7^D(L/^7"?)+CNF!LH?O60PEK
M9LRO9^S514+3<`>)GN(4#>W;8C*>X\W;S"6,%0N7.@V;G*E_"@*GX%">&FM)
M^^"C``````````````````````````````````````,```P````````?2```
M```````````#J1(````````````````````````````!QA(`````````````
M````````````````W!(````````````````````````````"VA$`````````
M```````````````````">1(`````````````````````````````@Q(`````
M````````````````````````T1$````````````````````````````!51(`
M```````````````````````````!Z!(`````````````````````````````
M\A(````````````````````````````",Q(`````````````````````````
M`````2`````````````````````````````":!(`````````````````````
M```````!;!(````````````````````````````"XA(`````````````````
M```````````"V2$````````````````````````````!JA(`````````````
M```````````````".A(````````````````````````````!(Q(`````````
M```````````````````"+!(````````````````````````````!$Q(`````
M```````````````````````!!1(````````````````````````````"MQ(`
M```````````````````````````!V!(`````````````````````````````
M$"`````````````````````````````!<Q(`````````````````````````
M```"@!(````````````````````````````"V!$`````````````````````
M```````"51(````````````````````````````"%Q(`````````````````
M````````````+"``````````````````````````````1A(`````````````
M```````````````"#Q(````````````````````````````!11(`````````
M```````````````````")1(`````````````````````````````8Q(`````
M````````````````````````P!(`````````````````````````````=!(`
M```````````````````````````"D!(````````````````````````````"
MFB(````````````````````````````!F1(`````````````````````````
M```!TQ(`````````````````````````````I!(`````````````````````
M```````""1(````````````````````````````"'A(`````````````````
M```````````!-Q(`````````````````````````````YA(`````````````
M```````````````!\1(````````````````````````````"B1(`````````
M```````````````````"0!(````````````````````````````"QA(`````
M```````````````````````"`A(````````````````````````````!LA(`
M````````````````````````````CQ(````````````````````````````!
ME!(````````````````````````````!8!(`````````````````````````
M````X1(````````````````````````````!C1(`````````````````````
M````````LQ$````````````````````````````!X!(`````````````````
M```````````!?A$````````````````````````````"OQ(`````````````
M```````````````"J1(````````````````````````````!+!(`````````
M```````````````````"8!(`````````````````````````````5!(`````
M```````````````````````"3A(````````````````````````````"<A$`
M```````````````````````````#LA(```X```````!$Z`````````!T```$
M%Q(```X````````[Z`````````9B```"TQ(```X````````FB`````````*$
M```#&1(```X````````UN``````````&```#1Q(```X```````!"4```````
M``*8```$/1(```X````````UP`````````)2```#_1```!@```````#`B```
M```````````#*A(```X````````X&``````````V```#71(```X````````Z
M(`````````".```#OA$``!````````!@N``````````$```#VA(```X`````
M``!=>`````````$H```#Y1(```X````````T,``````````\```$$A```!@`
M``````#`L``````````````$*Q(```X````````Z\`````````#R```#S1``
M`!<```````#````````````````#@1(```X````````X4`````````!.```$
M)!```!<```````#`B``````````````$2A$``!<```````#`@``````````(
M```#-Q(```X```````!@<``````````"```#TQ(```X````````I$```````
M```````#[1(```X```````!@``````````!J```$"1(```X```````!=````
M``````!R```#SR```!<```````#````````````````#EQ(```X````````Z
ML``````````\```#:Q(```X````````TT`````````#H```#C1(```X`````
M``!>H`````````%>```$5!(```X````````XH`````````%Z`%]?9VUO;E]S
M=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES
M=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`
M4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!0
M97)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U
M;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L
M7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L
M7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T
M`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO
M8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&]P96XV-`!R96%D`%]?97)R
M;F]?;&]C871I;VX`;'-E96LV-`!P=&AR96%D7V=E='-P96-I9FEC`%]?<W1P
M8W!Y7V-H:P!E>&ET`'-T<FYC;7``<W1R<F-H<@!C;&]S961I<@!?7W-T86-K
M7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P:60`
M<W1R9'5P`'-T<G1O:P!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC
M<'D`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED
M`')E861L:6YK`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S
M<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!?7VQI8F-?<W1A<G1?;6%I;@!?
M7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`;&EB<&5R;"YS;P!L:6)P=&AR
M96%D+G-O+C``;&EB8RYS;RXV`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N
M86UE`%]?;&EB8U]C<W5?9FEN:0!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R
M7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`
M<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A
M;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS
M7VEN:70`7U]L:6)C7V-S=5]I;FET`%]?8G-S7W-T87)T`'-H85]I;FET`%]E
M;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?
M9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C(`1TQ)
M0D-?,BXT`$=,24)#7S(N,RXR`$=,24)#7S(N,RXT`"]U<W(O;&EB+W!E<FPU
M+S4N,C8N,2]S,SDP>"UL:6YU>"UT:')E860M;75L=&DO0T]210`````````"
M``,``0`"``(``0`!``$``@`!``(``0`"``(`!``"``4``@`!``(``0`!``(`
M`@`!``$``@`"``(``@`!``$``@`!``(``0`!``$``@`"``4``@`!``(``@`!
M``$`!@`"``8``@`"``4``0`%``$``@`%``$``@`!``(`!@`!``(``0`"``(`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$```````$``0```O\````0````(`UI:1(````%```$80``````
M`0`$```##P```!``````#6EI%`````8```1K````$`EI&7(````$```$=0``
M`!`):1ET`````P``!($````0#6EI$@````(```1A`````````````+N(````
M``````P````````J$````````+N0``````````P````````IP````````+_X
M``````````P````````FB````````,`(``````````P```````#`"```````
M`,`0``````````P```````!BZ````````,`8``````````P```````!@O```
M`````,`H``````````P```````!AN````````,`P``````````P```````!A
MO````````,`X``````````P```````!B[@```````,!```````````P`````
M``!A'@```````,!(``````````P```````!B]@```````,!8``````````P`
M``````!B^@```````,!@``````````P```````!C`````````,"`````````
M``P```````!CG````````+^8````!0````H``````````````````+^@````
M"`````H``````````````````+^H````"P````H``````````````````+^P
M````#0````H``````````````````+^X````&@````H`````````````````
M`+_`````(`````H``````````````````+_(````(P````H`````````````
M`````+_0````)0````H``````````````````+_8````*0````H`````````
M`````````+_@````/`````H``````````````````+_H````/@````H`````
M`````````````+_P````10````H``````````````````+W@`````@````L`
M`````````````````+WH`````P````L``````````````````+WP````!```
M``L``````````````````+WX````!@````L``````````````````+X`````
M!P````L``````````````````+X(````"0````L``````````````````+X0
M````"@````L``````````````````+X8````#`````L`````````````````
M`+X@````#@````L``````````````````+XH````#P````L`````````````
M`````+XP````$`````L``````````````````+XX````$@````L`````````
M`````````+Y`````$P````L``````````````````+Y(````%`````L`````
M`````````````+Y0````%0````L``````````````````+Y8````%@````L`
M`````````````````+Y@````%P````L``````````````````+YH````&```
M``L``````````````````+YP````&0````L``````````````````+YX````
M&P````L``````````````````+Z`````'`````L``````````````````+Z(
M````'@````L``````````````````+Z0````'P````L`````````````````
M`+Z8````(0````L``````````````````+Z@````(@````L`````````````
M`````+ZH````)`````L``````````````````+ZP````)@````L`````````
M`````````+ZX````)P````L``````````````````+[`````*`````L`````
M`````````````+[(````*0````L``````````````````+[0````*@````L`
M`````````````````+[8````*P````L``````````````````+[@````+```
M``L``````````````````+[H````+0````L``````````````````+[P````
M+@````L``````````````````+[X````+P````L``````````````````+\`
M````,`````L``````````````````+\(````,0````L`````````````````
M`+\0````,@````L``````````````````+\8````,P````L`````````````
M`````+\@````-`````L``````````````````+\H````-0````L`````````
M`````````+\P````-@````L``````````````````+\X````-P````L`````
M`````````````+]`````.`````L``````````````````+](````.0````L`
M`````````````````+]0````.@````L``````````````````+]8````.P``
M``L``````````````````+]@````/0````L``````````````````+]H````
M/P````L``````````````````+]P````0`````L``````````````````+]X
M````00````L``````````````````+^`````0@````L`````````````````
M`+^(````0P````L``````````````````+^0````1`````L``````````.MO
M\#``)+D$`!^G^_]@XQ#P```DP,```$\VP!```%`GXQ`0```$N0(`$:>$``,-
MX>-`\1``!.MO\-``!`?T!P?C$/`X`"3`$```3QW2!_`P$`CC$!`0``0'\0<`
M!P`'`,`0``!/'.,0$```!`?Q#1#C$!`,`!3`]/___^4`````P!```$\0XQ`0
M```$!_$-$.,0$`P`%,#T____U0```!C`$```3P3C$!````0'\0T0XQ`0#``4
MP/3____%````,,`0``!.^.,0$```!`?Q#1#C$!`,`!3`]/___[4```!(P!``
M`$[LXQ`0```$!_$-$.,0$`P`%,#T____I0```&#`$```3N#C$!````0'\0T0
MXQ`0#``4P/3___^5````>,`0``!.U.,0$```!`?Q#1#C$!`,`!3`]/___X4`
M``"0P!```$[(XQ`0```$!_$-$.,0$`P`%,#T____=0```*C`$```3KSC$!``
M``0'\0T0XQ`0#``4P/3___]E````P,`0``!.L.,0$```!`?Q#1#C$!`,`!3`
M]/___U4```#8P!```$ZDXQ`0```$!_$-$.,0$`P`%,#T____10```/#`$```
M3ICC$!````0'\0T0XQ`0#``4P/3___\U```!",`0``!.C.,0$```!`?Q#1#C
M$!`,`!3`]/___R4```$@P!```$Z`XQ`0```$!_$-$.,0$`P`%,#T____%0``
M`3C`$```3G3C$!````0'\0T0XQ`0#``4P/3___\%```!4,`0``!.:.,0$```
M!`?Q#1#C$!`,`!3`]/___O4```%HP!```$Y<XQ`0```$!_$-$.,0$`P`%,#T
M___^Y0```8#`$```3E#C$!````0'\0T0XQ`0#``4P/3___[5```!F,`0``!.
M1.,0$```!`?Q#1#C$!`,`!3`]/___L4```&PP!```$XXXQ`0```$!_$-$.,0
M$`P`%,#T___^M0```<C`$```3BSC$!````0'\0T0XQ`0#``4P/3___ZE```!
MX,`0``!.(.,0$```!`?Q#1#C$!`,`!3`]/___I4```'XP!```$X4XQ`0```$
M!_$-$.,0$`P`%,#T___^A0```A#`$```3@CC$!````0'\0T0XQ`0#``4P/3_
M__YU```"*,`0``!-_.,0$```!`?Q#1#C$!`,`!3`]/___F4```)`P!```$WP
MXQ`0```$!_$-$.,0$`P`%,#T___^50```EC`$```3>3C$!````0'\0T0XQ`0
M#``4P/3___Y%```"<,`0``!-V.,0$```!`?Q#1#C$!`,`!3`]/___C4```*(
MP!```$W,XQ`0```$!_$-$.,0$`P`%,#T___^)0```J#`$```3<#C$!````0'
M\0T0XQ`0#``4P/3___X5```"N,`0``!-M.,0$```!`?Q#1#C$!`,`!3`]/__
M_@4```+0P!```$VHXQ`0```$!_$-$.,0$`P`%,#T___]]0```NC`$```39SC
M$!````0'\0T0XQ`0#``4P/3___WE```#`,`0``!-D.,0$```!`?Q#1#C$!`,
M`!3`]/___=4```,8P!```$V$XQ`0```$!_$-$.,0$`P`%,#T___]Q0```S#`
M$```37CC$!````0'\0T0XQ`0#``4P/3___VU```#2,`0``!-;.,0$```!`?Q
M#1#C$!`,`!3`]/___:4```-@P!```$U@XQ`0```$!_$-$.,0$`P`%,#T___]
ME0```WC`$```353C$!````0'\0T0XQ`0#``4P/3___V%```#D,`0``!-2.,0
M$```!`?Q#1#C$!`,`!3`]/___74```.HP!```$T\XQ`0```$!_$-$.,0$`P`
M%,#T___]90```\#`$```33#C$!````0'\0T0XQ`0#``4P/3___U5```#V,`0
M``!-).,0$```!`?Q#1#C$!`,`!3`]/___44```/PP!```$T8XQ`0```$!_$-
M$.,0$`P`%,#T___]-0``!`C`$```30SC$!````0'\0T0XQ`0#``4P/3___TE
M```$(,`0``!-`.,0$```!`?Q#1#C$!`,`!3`]/___14```0XP!```$STXQ`0
M```$!_$-$.,0$`P`%,#T___]!0``!%#`$```3.CC$!````0'\0T0XQ`0#``4
MP/3___SU```$:,`0``!,W.,0$```!`?Q#1#C$!`,`!3`]/___.4```2`P!``
M`$S0XQ`0```$!_$-$.,0$`P`%,#T___\U0``!)C`$```3,3C$!````0'\0T0
MXQ`0#``4P/3___S%```$L,`0``!,N.,0$```!`?Q#1#C$!`,`!3`]/___+4`
M``3(P!```$RLXQ`0```$!_$-$.,0$`P`%,#T___\I0``!.#`$```3*#C$!``
M``0'\0T0XQ`0#``4P/3___R5```$^,`0``!,E.,0$```!`?Q#1#C$!`,`!3`
M]/___(4```40ZV_P,``DP-```#V=X_#_./]QXS#PJ``DXT#PH``D4"#PM+)/
M`!#K$0`@``VR3P`104#PH$$P\*A!(/"TT@?PP!`HP.7___^_Q$@``$QLQ"@`
M`$Q]N00`-,#E```<S,08``!,?94`$`"GA`"XQ+@``$Q6XR"P```6P.7___[T
ME@(D^N,@L```%L#E___^[%BP\+26`23Z["L`!`#8I[H``[D4`")!$-``XR`0
M```AIR0`R>LB``,`#<#E____!,`0```>)^,P\*@`!.-`,```!.,0(`@`).-`
M(```),08``!,CN,0(!``),0K``!,F,`0```>$>,0(!@`)%A0\+2G7@`!I\0`
MFT$P,`BG"``$[$7__P#8N10`$..@,```!.L1``,`#>.A(```)*<*``&G.P`(
MIT;_\:=:``.Y%`!5ZU4``P`-014@`+D4`$NY!`!2Y4@0````IVD``,`P```&
M1\0H``!,8,#E___\+1BR$B*GA`!;Q"@``$Q60:#PO,#E___^`;D$`#K`(```
M'*W`Y0```0&Y`@`BIX0`.L0H``!,0L#E___[W\#E___]++)/`!"Y%``KZQ$`
M(``-LD\`$=4'\,`0**=T`%?C0/$X``3K;_#X``0'],#E___\U,0K``!,(;D"
M`"*GA`!)P.7___U*Q+@``$N3XR"P```6P.7___XQD@`I(:?T_S7`$```3`+C
M(!````*GA``=P.4```XBI_3_O<0H``!+_<#E___\2ABRI_3_H*=9`""G]/^$
MQ#@``$N0P"```!S[P.7___X:N00`.L`@```<'L#E````FL0K``!+U[D"`"*G
MA/^8I_3_UL#E___]IJ<I``'`Y?___4$'!P<'04#P".,P\```!*<)__"Y@`#P
MI_O_4-<'\`#P`.OO\*``)$%P\*#`8```&YW`4```&V+`(```2UOC("````3`
MY?___:T```<'P!```$N8P"```$N5N2``$J>$``K$&```2R:Y`@`1IX0``P?Q
M!_X'!\`0``!+A,`@``!+@;D)`!+K$0`#``KK,0`_``RY"``QZS,``0`*N0(`
M,Z>$``K$&```2PFY`@`1IX0``P?Q!_[KO_!8`"3`L```2V'C\/]@_W&5`+``
MIW0`%<`0``!*_^,0$````J>$``C$*```2P_`Y?___*S`Y?___[&2`;``XT#Q
M$``$Z[_P^``$!_0'!\#T____N`<'ZV_P,``DX_#_8/]QN0(`@J>$`&;$&```
M2K;C<!````*GA`!>XQ"```"4$A&GA``&IQX`/:=T`#&GF```XZ!P```"IX0`
M(;D$`&.Y%`"9N00`M[D$`$FY!``XN00`*L#E___[N1(BIW0`"$$9H`"5/1``
MIX0`(T&PL`CCH+````*G=/_IN00`*N-`\1``!.MO\-``!`?TN00`F$&0D`'C
M$)```)02$:>$``:G'@`]IW3_]AN8I_3_Q+D)`+=!J:`!Z[L``P`*N00`*E"P
M8`#C0/$0``3K;_#0``0']*>I``"G]/_2!P<'!^NO\%``)+)/`!#C\/]0_W'K
M$0`@``VY!`"BLD\`$4&P\*32!_"H$"BY!``[N00`*L#E____=+D"`"*GA``O
MQ"@``$HMXQ#PI``4ZQ$``P`-XQ`@```(XR`0"``$XR`0```DN0(`(J>$_^%!
M$!`(XR`0"``$XR`0```DN0(`(J=T__:Y!``[N00`*L#E____1[D"`"*G=/_5
MLD\`$.L1`"``#;)/`!'5!_"H$"BG=``)XT#Q(``$ZZ_Q```$!_3`Y?___$4'
M!P<'ZV_P,``DLD\`$./P_TC_<>L1`"``#;)/`!&Y!`"RN00`H]('\+`0*)4]
M,`"G=``$0:`P`:<(``"Y!``:IYD``+)>`)&G%/_^N0D`FD$P\*RY!``KP.7_
M__[^N0(`(J>$`+BG"```IQD``+D$`#*R7@`3IQ3__KD)`!*Y(0`9IZ0`C./0
M\*P`%,2(``!)I.O=``,`#>,0L```E!(1IX0!#Z<>`#VGA`$+N00`&Z?T``:G
M+@`]IX0`"D$0$`'C(!```)02(J=T__:Y"0`;N10`$;D$`'U!*1`"XW"````(
MP.7___H1XR!P```DN0(`(J>$`/#C$+```)#C0(````3C,/"L`!3K,P`#``WC
M,T````1"$#``0;"P`<`;````_Z=T`!*G]``4XQ"P``"00A`P`4&PL`%!,#`!
MP!L```#_IX0`!J<>`#VG=/_PDCTP`*<9``#C(:```)!"(3`!IQL``;D"`"*G
M=/_WIR@``+)/`!"Y%``BZQ$`(``-LD\`$=4'\+`0**=T`*GC4/$H``3K;_#H
M``0']>,0H```D$(0(`!!H*`!02`@`;D"`!&GA/_>XQ"@``"00A`@`$&@H`%!
M("`!N0(`$:=T_^BG]/_/Q(@``$D!XV"````$XQ!@```"IX0`<;D$`!:G*```
MI_0``Q@G['(``0#801`0".,P$````J=T__>G*@`#N10`(NLB``,`#<`0``!)
M6N,0$```$J=T`#7`$```25+E3!````'`Y?__^6BY`@`2XQ#PH``DIX0`1[D$
M`#:Y%`!GZ]8``P`-N00`3<#E___YU>,0\*``!.,0@```)*=K``'C$/"@``3K
M9@`#``U!%A``Y4@0````4'#PK*?T_P>Y!``RN00`)L#E___Z)^,@\*``).,@
M@```)+D"`"*GA``3N10`9^O6``,`#:?T_]FG&0``I_3_":<I`!"G>```I_3_
MI:<H__^G]/]-P.7___K5!P<'!^MO\#``)+)/`!#C\/[`_W'K$0`@``VR3P`1
MN0(`HM('\3@0**>$``:5`*``IW0`%;)/`!#K$0`@``VR3P`1U0?Q.!`HIW0`
ME>-`\;``!.MO\7``!`?TP.7___N5N0(`DJ>$_^A!</"HN00`*<#E___Z"KD"
M`"*GA`!K0;`@$\`0```8RZ<(``"Y!``KLET`$J<4__ZGA/_JP!```!B_N00`
M*[)=`!*G%/_^IX3_W[D$`!JG*0``N00`.[)>`"&G%/_^IQD``+D)`"JY!`!J
MLEX`$Z<4__ZY"0`;&B&G*@`"N10`(L#E___XGN.P\*``)+D$`(+`4```&).G
M2?__ISD``<#E___['[D$`$>Y!``XIRD``<#E___X=J<N__^Y!``HIX0`"U@0
M\,#`&P``\`"G'D``IX0`&,#E___Z=+D$`"C`Y?__^K^G]/^0N00`*<#E___X
M.+D$`"K`Y?__^).G]/]HP.7___].I_3_ZL#E___Z&0<'!P>R3P`0ZQ$`(``-
MLD\`$>N_\%@`)+D$`#+C\/[(_W&Y!`"R04#PH*<I``'2!_$P$"C`Y?__^/P2
M(J=T`#08$E@@\+C`*P``\`"G+D``IX0`',(M``"@`*>$`!>Y%``ALD\`$.L1
M`"``#;)/`!'5!_$P$"BG=``;XT#QJ``$Z[_QD``$!_2Y!``KISD``L#E___Z
MCA`2IQK__X@0`!^G]/_?IQ@``*?T_]O`Y?__^<`'![)/`!#K$0`@``VR3P`1
MZW_P.``DX_#_6/YQXU#PH`%QN00`DKD$`'-!L/"@ITD/_[D$`#O`(```%^+2
M!U``$"C`Y?__^(P2(J?$`%;L$O__`-C$.```1S^Y%`"A6(`P`$$Z\*"5`#``
MIX0`-;D4`**Y!`!*ISD`+[D$`"O`Y?__^(ZY`@`BIX0`*;D6`"C`Y?__^<6Y
M!`!:N00`2[D$`#G`Y?__^1RR3P`0XR#PH`%QZQ$`(``-LD\`$=4'(``0**=T
M`"WC0/$8`03K?_#@`00']!(1IW3_SKD6`"C`Y?__^9ZY!`!'N00`.<#E___W
M]Z?T_]O$&```1NY8@!``N18`*,#E___YB[D$`$>Y!``YP.7___?DI_3_R,#E
M___Y+[)/`!#K$0`@``VR3P`1N00`,J=)$`#KO_!8`"3C\/]8_G'C4/"@`7%!
ML/"@T@=0`!`HN00`*\#E___VT>,0+___<;DA`!NGQ``0ZR\O__]5IW0`"[GI
ML"&2`!``XQ`?__]QIR<`+*<Y`"^Y!``KP.7___FEN0(`(J>$`#"Y(0`KIR0`
M1+D$`"O`Y?__^"BR3P`0XS#PH`%QZQ$`(``-LD\`$=4',``0**=T`#3C0/$8
M`03KO_$``00'])4O$`"GA/_-ISD`+[D$`"O`Y?__^7>Y`@`BIW3_U+)/`!#C
M(/"@`7'K$0`@``VR3P`1U0<@`!`HIW0`#\`@```6Z^N_\0`!!,#T___WZY(`
M(`"G]/^\P.7___BD!P>R3P`0ZQ$`(``-LD\`$:=)``*G.0``ZX_P0``DX_#_
M4.]QXU#PJ!!QN00`@M('4``0*,#E___VYZ<K___LDC"``%6Y`@"9IZ0`"Z>;
M___`$?__``"Y@0"1IYL``;GID)*Y`@"9IT0`6$&P\*#`H```1GZG20``N00`
M.;D$`"C`Y?__]L'`00`!``BY!``[N00`*,#E___XQ[D4`"+"+@````>GQ``Q
MXR*_^/]QN2$`*Z>D``NG]``HXR`O__]QN2$`*Z=$`"'5!R``H`"G=/_VN>FP
MN;D(`"NR3P`0XS#PJ!!QZQ$`(``-LD\`$=4',``0**=T`!7C0/$@$`3KC_#P
M$`0'],*4``$``,*<__\``*=T_[&G*?__I_3_X,#E___X$@<'!P<'!^OO\'``
M),08``!%M>/P_V#_<>,@$```%L#E___X4,!0```VP<1(``!%NL`P```6/^OO
M\1``!,#T___XT0<'!P?K;_`P`"3C\/]8_W'$N```19+C(+```!;`8```%X7`
MY?__^"W`Y?___\[C(+```!;`Y?__^"2Y!`!6Y4CPH```P$````;0P#```!8?
MP.7___<6XT#Q&``$ZV_PV``$!_3K;_`P`"2R3P`0X_#_2/UQZQ$`(``-XR#P
ML`)QLD\`$=('(``0*$&P\*[CH/"O`7'`Y?__]W3`$```%@CC$/"@`"2Y!`!B
MP%```!7ZITD0`:<Y``&Y!``KP.7___A@N00`*Z=)$`"Y!``ZP.7___9W$B*G
M1``TN00`LJ<J``&Y%``BP.7___6[N0(`DJ>$``^Y%`"[N00`.KD$`$O`Y?__
M^'Y!&Y``D@`0`+)/`!#C,/"P`G'K$0`@``VY!``ILD\`$=4',``0**=T``WC
M0/$H`@3K;_#H`@0']*>9``"G]/_FP.7___=+P/3___^,!P?K;_`P`"2R3P`0
MX_#^L/YQZQ$`(``-XT#Q2`%QLD\`$;D$`+*Y!`"3P"```!6903#PM-('0``0
M*,#E___Z$*<Y`"^Y!`"BN00`*\#E___W+[D"`"*GA``BN00`.\`@```5A,#E
M___ZT[D$`"NR3P`0XS#Q2`%QZQ$`(``-LD\`$=4',``0**=T`./C0/'``03K
M;_&``00']+D$`"G`Y?__]C;`,```%6C`Y?__]8"Y`@!BIX3_T\"0```5(T&`
M\4A!</"XE0!@`*>$`(RY`@"JIX0`#J<(``"Y!``6N00`*K)=`!*G%/_^IX0`
M;+D$`!:G"```IRD``+)>`"&G%/_^N0D`)N,2;___<;DA`&&GI``;E2\0`*=T
M`!>YZ6`QD@`0`.,0'___<:<W`'.G"```IRD``+D$`!:R7@`AIQ3__KD)`":G
M"```IQD``+D$`#NR7@`3IQ3__KD)`!M!$2`!PAX```__IR3_><`0```5!>.P
M\*@`).,0\*``),!0```59J=)$`"G.0`!N00`*,#E___W3;D$`$>Y!``XIRD`
M`<#E___TI!(BIW0`#%@0\-#`&P``\`#"'0``@`"GA``OP#```!39IRD``,#E
M___T[[D"`&*GA/]"E0!@`*=T_WBY`@"JIX0`#J<(``"Y!``9N00`*K)=`!*G
M%/_^IX3_XJ<I``'`8```%'RG]/^=E2\0`*>$_X:G]/^+ISD``;D$`"C`Y?__
M]O,2(J=T_\NY!``XP"```!29P.7___GHN00`*,#E___U8Z?T_Q+`Y?__]AX'
M!P<'!P?KO_!8`"2G.0`OX_#_8/]QN00`LL#E___VOKD"`"*GA``$0;`@`;D$
M`"OKO_#X``3`]/__]4`'![D"`!*GA``<E0`0`*>$`!BY!`!!IP@``*<Y``"R
M7@`TIQ3__KGI$!.G&P`!PAX``!``IR0`"\#T___\M<`@```4&,#T___U&Z<I
M```'_@<'LD\`$.L1`"``#;)/`!'KO_!8`"3`(```%$'C\/]0_W'2!_"H$"A!
ML/"DP.7___D;P"```!0XP.7___D5P"```!0VP.7___D/P"```!0UP.7___D)
MP"```!0SP.7___D#P"```!0UP.7___C]P"```!0'P.7___CWP"```!0OP.7_
M__CQP"```!0NP.7___CKP"```!0MP.7___CEP"```!/TP.7___C?N00`.\`@
M```4),#E___X8[D"`#*GA``(P"```!00P.7___DQN00`.\`@```4&\#E___X
M4;D"`#*GA``(P"```!0:P.7___D?N00`.\`@```4&,#E___X/[D"`#*GA``D
MP"```!.YP.7___D-P#```!09P"```!/0P.7___D$LD\`$.L1`"``#;)/`!'5
M!_"H$"BG=``=XT#Q(``$Z[_Q"``$!_2Y!``[P"```!/RP.7___@1N0(`,J>$
M_]K`(```$[G`Y?__^-^G]/_2P.7___4:!P<'!P<'LD\`$.L1`"``#;)/`!'K
M[_!P`"3`(```$Z'C\/]0_W%!,/"DT@?PJ!`HP.7___?GN0(`(J>$`!/C("``
M`)"Y`@`BIX0`#,`G````,+D#`"+L(C^_`56G]``$IR@``+)/`!"Y%``BZQ$`
M(``-LD\`$=4'\*@0**=T``GC0/$@``3K[_$@``0'],#E___TT`<'Z^_P<``D
MX_#_8/]QP.7___*FP.7___)SN0(`(J>$``SC("````3C0/$0``3K[_$0``0'
M]*<I``"G]/_W!P<'!^MO\#``)+)/`!#K$0`@``VR3P`1X_#_0/]QN00`LD$P
M\+3`(```$VO2!_"X$"C`Y?__]WVY!``[N0(`HJ>$`#^5`*``IX0`.\#E___R
MJ+D"`"*G=``ZIP@``+D$`!NY!``ZLEX`(:<4__ZG&0``N00`:[GIL+*R7@`3
MIQ3__KD)`!I!*Q`"P.7___*IP!```!+;XZ#PJ``DXQ#PH``DN00`LJ<Y``'`
M4```$SFG2?__P.7___4DN00`.\`@```3'\#E___X#+)/`!#K$0`@``VR3P`1
MU0?PN!`HIW0`">-`\3``!.MO\/``!`?TP.7___0V!P<'!P<'LD\`$.L1`"``
M#;)/`!'K;_`P`"2Y!`#OX_#^"/]QI^O_^&"`X`#2!_'H$"C`,```0?[`$```
M0@=!</#$TA?PR#``N00`DKD$`#?`(```$G32+_#X$`#`$```0@W2%_#@$`#`
MY?__]N>Y`@"RIX0`!I4`L`"G=`$SP.7___\HN0(`LJ>$`3BY!``;IP@``*<I
M``"R7@`AIQ3__KD)`"OK(@`!``VG*P`!P.7___(<XQ"P``"0N00`HAAAN0(`
M$:>$`!ZY!`"*N80`9KD$`"C`4```$J6G2?__ISD``<#E___TDN,0L`$`D$&P
ML`%!@(`"&&&Y`@`1IW3_Z.,@\/@``J>$`+Q!L/$`I_0`":>[``CC(+_X_P*G
MA`"QN00`-\#E___VB;D"`(*GA/_RE0"``*>$_^[`Y?__^8(2(J>$_^BY!``H
MP.7___+.N0(`(J>$`)6G"```N00`$J>Y``"R7@"QIQ3__KD$`#JG&0``N0D`
MLK)>`!.G%/_^N0D`&KD$`&(:L:>Z!`2Y%`"[N00`*\"````1WL#E___QI<`0
M```21N.@\+``).,0\*@`)..`\*``)+/!`(+`4```$C.G2?__ISD``<#E___T
M';/-`"BG.0'`P.7___,&IR[__Z=T``O`Y?__\L]8$"``IQX`$:=T`9Q!0/$H
ML\T`.*<I``'`Y?__\C`8HA(BIW0`"U@0\4#`&P``\`"G'D``IX0`J,08``!`
M]+/-`&CC4)````3`0```$AWC(!````2G.0`!I[D``,#E___S+K)/`!"Y!``K
MZQ$`(``-LD\`$=4'\>@0**=T`?UH@/'PXT#R:``$ZV_R*``$!_2GB```N10`
M&.L1``,`#>.Q\,@``J>$`".5`+``IX0`'Z>*``&Y!``KP.7___C,$B*GA/_J
MN00`*\#E___R&+D"`"*G=/],N10`&.L1``,`#>.Q\,@``J=T_^&G*0``I_3_
M/L#E___^%[D$`"O`Y?__\?ZY!`"RI_3_KJ>H``"Y%``:ZQ$``P`-XR'PX``"
MIX0`):>J``'C(?#@``2Y!``WP.7___6,N0(`$J>$_^J5`!``IX3_YL#E___Q
MV;D"`+*G=/ZGN10`&NL1``,`#>,A\.```J=T_]^G*0`-P+```!%>P.7___##
MIV@`4[D$`**G]/ZM6&#Q1,#E___P6!EBIW3_5%@0\4#`&P```?^G'@'`IW3_
M2[D$`"O`Y?__\*>Y!``WN00`LL`@```1C\#E___U1;D"`#*GA`#8XR"0```$
MP.7___L/N0(`<J>$`,ZG"```IQD``+D$`">R7@`2IQ3__KD)`!>G'@`#I\0`
M'[D4`"'`,```$6SC(G_\_W&R70`RIQ3__J=T`!&G'@`$IX0!!J<:__RY%``1
MXQ%___]QE2\0`*>$`/O`Y?___0L2(J=T``ZY!``GISD``,#E___RM;D$`)(2
M(J=T`)3`,```$-S`(```$*'`Y?__]<?`D```$:FSS0!HP.7___'/P%```!$\
MXR#PJ``DXX#PH``DXY#PL``DITG__Z<Y``&Y!``KP.7___*ZI_0`+,#E___Q
M=5@0(`"G'@`1IW0`+J>J``&SS0!HP.7___&HN10`&N,@\*@`)..0\+@`)..`
M\*``).,0\+``),!0```1#J=)__^G.0`!N00`*\#E___RCJ<Y`<"Y!``KP.7_
M__%WIR[__Z>$_\VSS0`HP.7___(^N00`.\`@```0$L#E___U9KD$`"O`Y?__
M_/6G]/Z3N10`$>,0\*``)+/-`&C$&```/VGC4)````3`0```$';C(!````2G
M.0`!I[D``,#E___QI:?T_G?C<)````2G]/\QP.7___C;N0(`<J=$_VFG20``
MXS!_]O]QN00`*<#E___OS:=)``9!,/&YN00`*<#E___QU,`0```P'=4%$`#Q
MN:=T_T[C,'_._W&G20``N00`*4&@\;^SS0!HP.7__^^NN00`.KD$`"FG20`H
MP.7___&UP!```!#GXZ#PJ``DD@#QY^.`\*``),!0```0;^,0\+``)*=)__^G
M.0`!N00`*\#E___Q^Z?T_WCC$)`(``*GA/\$IP@``*<I``"Y!``QLEX`(Z<4
M__ZY"0`APBX````#I\3^\^,R'_S_<<`@```00K)=`".G%/_^N>*`<:?T_N7`
MY?__\0('!P<'!P?KC_!``"2R3P`0ZQ$`(``-LD\`$>/P_U#_<<2X```^F^,@
ML```%M('\*@0*$&@\*3`Y?__\32Y!`"2XR"P```6P.7___$LN00`.M(`(+F0
MN,`@```/7<#E___SN;D"`"*GA``&E3$@`*>$`-K`Y?__^O+C(+```!;`Y?__
M\1"G60`#ITD``<`P```0&L#E___O5KD"`)*GA``>XR"P```6P.7___#\XQ"0
M$``$P$```!`(XS`0```$P.7__^]0XQ"0$``$XQ`0```$D4`0#:=T`,'C(+``
M`!;`Y?__\."G60`#ITD``<`P```/[L#E___O)KD"`)*GA``?N00`.L`@```.
MZ\#E___S8KD"`(+C(+```!:GA`"*P.7___#`XQ"0$``$N00`2.,P$```!,#E
M___O%>,@L```%L#E___PK[D$`)+C(+```!;`Y?__\*>G20`!P#````^XP.7_
M_^X_P$````^]N00`,KD$`"G`Y?__[O7C(+```!;`Y?__\(^2`""YN00`.L`@
M```.H<#E___S'<0K```^6KD$`+*Y`@`BIX0`**<Y`<"Y!``KP.7__^_EIRX`
M$:>$``KL$@`!`-C"'P````&G)`!5LD\`$.L1`"``#;)/`!'5!_"H$"BG=`!9
MXT#Q(``$ZX_P\``$!_3$*```/B_`Y?__^]#$*P``/B6Y!`"RN0(`(J=T_\W`
M(```#VC`Y?__\%&5`"`!IX3_*:?T_R3`Y?__\#C$&```/A'C()`0``3C,!``
M``3C("````3`Y?__]AVG]/]TXR"P```6P.7___`AXQ"0$``$XS`0```$P.7_
M_^^XI_3_,L08```][[D$`%*Y!`!+P"````]!XS`0```$P.7___`6P.7__^^S
MZZ_P4``DX_#_8/]QN00`LL#E___YK,#E___YC;D$`*+`Y?__^HP2(J>$`!>Y
M`@"[IX0`$Y4`L`"GA``/N00`*J=)``3`,```#G+`Y?__[EL2(J>$``GC0/$0
M``3KK_#P``0']+D$`"OKK_#P``3`]/__]*D'!P<'LD\`,*=9``CK,P`@``WK
M;_`P`"2R3P`QX_#\V/]Q0;`@.$$0\*"Y!`!!T@?S(#`HXS"P```$ZP,`(``,
MXP!````DP#H`````XS!`"``D0;"P"*=+`!"G5__MITD`0.,P$&@`!.,P$$``
M@N,P$!``@N,P$```@NQ3(+\A5>Q3(#X!5N-0$(``)*<;``BG1__IX[`@"``$
MXY`@$``$XP`@&``$XQ#PH``$N><`2<(:6H)YF;F``$OC$"`@``BY@@!`XU`@
M```$[(4@OR55[(4@.@56N0@`@>L;``(`#+D(`(3L&P`A'E;C0/"H``3L<2"_
M`%7"2EJ">9FYYW`YN8``-;F"`#G`B@````"YZ`!DZ]@`&P`,N0@`8^S8(#H%
M5NM%``(`#+D(`&WL10`A'E;`:@````"Y@@`4ZS8`&P`,N8``&.PV(#H%5KF"
M`!>SP0`CXZ#PN``$XS#PL``$PJI:@GF9PCI:@GF9N0@`I[D(`#FSS0!RN0@`
M,>L8``(`#.P8`"$>5KGG$(3`2@````"Y@`"&N8(`A+D(`#>YZ*!XXX#PP``$
MPHI:@GF9N>A`2,`Z`````.R!(+\`5;/!`"3CH/#(``3K1@`"``S"JEJ">9GL
M1@`A'E:Y"`"HN8(`%+F``!.Y@@`8L\T`@NO3`!L`#+D(`!CLTR`Z!5;K@P`"
M``RY"`!][(,`(1Y6P'H`````N00`.+GG@(3`2@````"Y@`"'N8(`A+GHH&CC
M@/#0``3"BEJ">9FYZ$!([(,@OP!5L\$`).O7`!L`#.M'``(`#.S7(#H%5NQ'
M`"$>5KD(`!VY@@`TP!H`````XZ#PV``$N8``,<*J6H)YF;F"`#BY"`"HL\T`
M@NO1`!L`#+D(`#CLT2`Z!5;K@0`"``RY"`!M[($`(1Y6P&H`````N00`&+GG
M@(3`2@````"Y@`"&N8(`A+GHH'CC@/#@``3"BEJ">9FYZ$!([($@OP!5L\$`
M).O6`!L`#.M&``(`#.S6(#H%5NQ&`"$>5KD(`#VY@@`4P#H`````XZ#PZ``$
MN8``$\*J6H)YF;F"`!BY"`"HL\T`@NO3`!L`#+D(`!CLTR`Z!5;K@P`"``RY
M"`!][(,`(1Y6P'H`````N00`.+GG@(3`2@````"Y@`"'N8(`A+GHH&CKUP`;
M``SC@/#P``3"BEJ">9FYZ$!([(,@OP!5[-<@.@56L\$`)+D(`!WK1P`"``S`
M&@````#L1P`A'E;CH/#X``2Y@@`TPJI:@GF9N8``,;D(`*BY@@`XL\T`@NO1
M`!L`#+D(`#CLT2`Z!5;K@0`"``RY"`!M[($`(1Y6P&H`````N>>`=,!*````
M`+F``':Y@@!TN00`&+GHH(?C</$```3">EJ">9FYZ$!'['$@OP!5L\$`).O6
M`!L`#.M&``(`#.S6(#H%5NQ&`"$>5KD(`#VY@@`4P#H`````XZ#Q"``$N8``
M$\*J6H)YF;F"`!>Y"`"GL\T`<NO3`!L`#+D(`!?LTR`Z!5;K<P`"``RY"`"-
M[',`(1Y6P(H`````N00`-[GG<'3`2@````"Y@`!XN8(`=+GHH&?C</$0``3"
M>EJ">9FYZ$!'[',@OP!5L\$`).M(``(`#.Q(`"$>5KF"`#3KV``;``SLV"`Z
M!5:Y"``=P!H`````N>00@[/-`#*Y@@"'Z]$`&P`,N0@`@^S1(#H%5NLQ``(`
M#+D(`&WL,0`A'E;`:@````#CH/$8``3"JEJ">9FY"`"GN><P=,!*`````+F`
M`':Y@@!TN00`$[GHH#?C</$@``3">EJ">9GKU@`;``RYZ$!'[-8@.@56['$@
MOP!5N0@`C;/!`"3`B@````#K1@`"``SKV``;``SL1@`A'E;LV"`Z!5:Y@@`4
MXZ#Q*``$N8``&,*J6H)YF;F"`!>Y"`"GL\T`<NQD(+\`5;D(`#VY"``7P#H`
M````ZW@``@`,Z],`&P`,['@`(1Y6[-,@.@56N>=PA+F``(.Y@@"&N0@`';GH
MH$C`&@````#K@P`"``SKT0`;``SL@P`A'E;LT2`Z!5;CH/$P``3"JEJ">9FY
M"`"F[&<@OP!5N8(`>+D(`$VYY!`WP$H`````XW#Q.``$Z]0`&P`,PGI:@GF9
M[-0@.@56N0@`=KF"`#:SP0`GN0@`.NMQ``(`#+D(`#WL<0`A'E;LV""_`%6Y
MYW!H[(,@OP!5N8``9.NH`!L`#+F"`&WLJ"`Z!5:SS0`2N>@0%NMD``(`#+D(
M`!KL9``A'E:YYV"GN8(`.N-`\4``!.NH``(`#,)*;MGKH>RH`"$>5KD(`$VY
M!`"*N1H`0[GGH*:Y!``TN8(`H>S1(+\`5>M-`!L`#.Q-(#H%5KD(`$/C,/%(
M``3L%""_`%7".F[9ZZ&Y&@`WN1H`.NNA`!L`#.RA(#H%5NM]``(`#+D(`#KL
M?0`A'E:YYW"HN8(`I./0\5``!.Q#(+\`5<+:;MGKH;D:`-:Y&@#:ZZ0`&P`,
M[*0@.@56ZV$``@`,N0@`VNQA`"$>5KGG8*>Y@@"CXQ#Q6``$[#T@OP!5PAIN
MV>NAN1H`&+D:`!KKHP`;``SLHR`Z!5:Y"``:ZX0``@`,XZ#Q8``$PJINV>NA
M[(0`(1Y6L\$`"NQ!(+\`5>NC``(`#+/!`&JSS0"@N1H`I^MT`!L`#+/!`">Y
MYX!VL\$`1[/-`';L<P`A'E:SS0`TN8(`T[/-`#+L-"`Z!5:SP0`CN00`.KD:
M`#VSS0#2N>=PJ+D(`#VY@@"A[-,@OP!5XQ#Q:``$PAINV>NAN1H`%NMM`!L`
M#.QM(#H%5KD:`!KKI``"``RY"``6[*0`(1Y6N00`:KGGH*?C0/%P``3"2F[9
MZZ&Y&@!(N><PBNPQ(+\`5>NC`!L`#.RC(#H%5KD:`$CKC0`"``RY"`!*[(T`
M(1Y6X]#Q>``$N>>`IL+:;MGKH;F"`*&Y!``=[-0@OP!5N1H`%[D:`!KKK0`;
M``SLK2`Z!5;K<P`"``SL<P`A'E:YZ*`QN>=PJ+F"`*3C$/&```3L0R"_`%7"
M&F[9ZZ&Y&@`6N1H`&NND`!L`#.RD(#H%5NMM``(`#+D(`!KL;0`A'E;CT/&(
M``2YYV"GPMINV>NAN8(`H[D$`#WLT2"_`%6Y&@`XN1H`.NNM`!L`#.RM(#H%
M5NN$``(`#.R$`"$>5KGHH$.YYX"FN8(`H>,P\9``!.P4(+\`5<(Z;MGKH;D:
M`#>Y&@`ZZZ$`&P`,[*$@.@56ZWT``@`,N0@`.NQ]`"$>5N/0\9@`!+GG<*C"
MVF[9ZZ&Y@@"DN00`3>S3(+\`5;D:`$:Y&@!*ZZT`&P`,[*T@.@56ZV$``@`,
M[&$`(1Y6N>B@%+GG8*>Y@@"CXT#QH``$[#$@OP!5PDINV>NAN1H`2+D:`$KK
MHP`;``SLHR`Z!5;KC0`"``RY"`!*[(T`(1Y6X]#QJ``$N>>`IL+:;MGKH;F"
M`*&Y!``=[-0@OP!5N1H`%[D:`!KKK0`;``SLK2`Z!5;K<P`"``SL<P`A'E:Y
MZ*`QN>=PJ+F"`*3C$/&P``3L0R"_`%7"&F[9ZZ&Y&@`6N1H`&NND`!L`#.RD
M(#H%5NMM``(`#+D(`!KL;0`A'E;CT/&X``2YYV"GPMINV>NAN8(`H[D$`#WL
MT2"_`%6Y&@`XN1H`.NNM`!L`#.RM(#H%5NN$``(`#.R$`"$>5KGHH$.YYX"F
MN8(`H>,P\<``!.P4(+\`5<(Z;MGKH;D:`#>Y&@`ZZZ$`&P`,[*$@.@56N0@`
M.N.@\<@`!,*J;MGKH>M]``(`#.Q]`"$>5KGG<-BY@@#4N00`2KD:`$;L8R"_
M`%6Y&@!-ZZ8`&P`,[*8@.@56Z]$``@`,[-$`(1Y6N>B@%+GGT$?CH/'0``2Y
M@@!#PJINV>NAN1H`J+D$`(JY&@"$[#$@OP!5ZT8``@`,ZZ,`&P`,[$8`(1Y6
M[*,@.@56N>B@:+GG0(VY@@`8XX#QV``$PHINV>NAN1H`A\!J`````+D$`'CK
MI@`;``SLIB`Z!5:Y!`"*N1H`<>.@\>``!+D(`'C"JH\;O-SK$P`"``RY&@"M
M[!,`(1Y6[-0@OP!5N>80A.Q!(+\`5;F``(:YY$`]N8$`@[D(`(K`>@````#C
MH/'H``3K-P`;``S"JH\;O-SL-R`Z!5:Y"`"MN0@`..N&``(`#.R&`"$>5NQH
M(+\`5;GF@-&YY&`4N8``U[F!`-&Y"`#:P#H`````XZ#Q\``$ZQ,`&P`,PJJ/
M&[S<[!,@.@56N0@`I+D(`!WK1P`"``SL1P`A'E;LU""_`%6Y@0"$N>30=KF`
M`(.Y@0"'N0@`BL`:`````.MQ`!L`#.QQ(#H%5KD(`'CK@P`"``SL@P`A'E;C
MH/'X``2Y@0!(PJJ/&[S<N8``0;D(`*:Y!``X[&@@OP!5N>1@C;F!`$BY"`!*
MP'H`````ZX<`&P`,[(<@.@56N0@`A.M!``(`#.Q!`"$>5N.@\@``!+F!`#3"
MJH\;O-RY@``WN0@`K;D$`!3LU""_`%6YY-!&N8$`-+D(`#K`B@````#K2``;
M``SL2"`Z!5:Y"`!#ZS<``@`,[#<`(1Y6XZ#R"``$N8$`$\*JCQN\W+F``!BY
M"`"FN00`<^QC(+\`5;GD8#VY@0`3N0@`&L!*`````.LT`!L`#.PT(#H%5KD(
M`#'K&``"``SL&``A'E;CH/(0``2Y!`"!N8$`<<*JCQN\W+F``'2Y"`"M[-$@
MOP!5N>30%KF!`'&Y"`!ZP#H`````XZ#R&``$ZQ,`&P`,PJJ/&[S<[!,@.@56
MN0@`IKD(`!?K=``"``SL=``A'E:Y!`!'N>9P>.QD(+\`5;F``'.YY&"-N8$`
M>+D(`'K`&@````#K@0`;``SL@2`Z!5:Y"`"'ZW,``@`,[',`(1Y6N>9P-+F`
M`#'CH/(@``3"JH\;O-RY"`"M[-<@OP!5L\$`*KGDT$:Y@0!#L\T`,L"*````
M`+D(`$/KJ``;``RY!``Z[#@@.@56ZZ$``@`,N0@`0[D$`#K`2@````#L,0`A
M'E:YYC`7[',@OP!5N8``&+GD<*VY@0`:L\$`0>NH``(`#.L4`!L`#+/!``'L
MJ``A'E;C$/(H``3"&H\;O-RSP0`AL\T`$.P4(#H%5K/!``&SS0`2N0@`8;D$
M`(JSS0`4N0@`%K/-`&#CH/(P``2Y"``6PJJ/&[S<[&@@OP!5N0@`K;GF@-.Y
MY&`WP!H`````N8``U+F!`-/K,0`;``RY"`#:[#$@.@56N0@`/>.@\C@`!,*J
MCQN\W+D(`*?L<R"_`%7K-``"``SL-``A'E;LTR"_`%6YYC!(N>30AKF``$&Y
M@0!(N0@`2NN'`!L`#.R'(#H%5KD(`(3K00`"``SL00`A'E;CH/)```2Y@0`T
MPJJ/&[S<N8``-[D(`*:Y!``4[&0@OP!5N>1@3;F!`#2Y"``ZP(H`````XZ#R
M2``$ZT@`&P`,PJJ/&[S<[$@@.@56N0@`K;D(`$/K-P`"``SL-P`A'E;LTR"_
M`%6Y@0`3N>30=KF``!BY@0`7N0@`&L!*`````..@\E``!.MT`!L`#,*JCQN\
MW.QT(#H%5KD(`*:Y"`!QZQ@``@`,[!@`(1Y6[&$@OP!5N8$`,;GD8(VY@``T
MN8$`.+D(`#K`>@````#CH/)8``3KAP`;``S"JH\;O-SLAR`Z!5:Y"`"MN0@`
M@^LT``(`#.PT`"$>5NS3(+\`5;F!`!.YY-!&N8``%[F!`!2Y"``:P(H`````
MXZ#R8``$ZT@`&P`,PJJ/&[S<[$@@.@56N0@`IKD(`$'K%P`"``SL%P`A'E;L
M<2"_`%6Y@0`QN>1P;;F``#BY@0`VN0@`.L!*`````..@\F@`!.MD`!L`#,*J
MCQN\W.QD(#H%5KD(`*VY"`!CZS@``@`,[#@`(1Y6N00`@[GF,#'LV""_`%6Y
MY-`7P&H`````N8``-+F!`#'K%@`;``RY"``Z[!8@.@56N0@`$^.@\G``!.LT
M``(`#,*JCQN\W.PT`"$>5KD(`*?L<2"_`%6YYC`8[(,@OP!5N8``%KGD@$VY
M@0`4N0@`&NM'`!L`#..@\G@`!.Q'(#H%5L*JCQN\W+D(`$&Y"`"MZQ8``@`,
M[!8`(1Y6N00`8;GF$!/LUB"_`%6YY-`XN8``%[F!`!/L-""_`%6Y"``:ZZ,`
M&P`,[*,@.@56N0@`&NNG``(`#.RG`"$>5KD$`'KCH/*```2Y@@!GPJK*8L'6
MN0@`J+GG0(:Y&@"H[$$@OP!5N00`BNND`!L`#.RD(#H%5NMC``(`#.QC`"$>
M5KGHH#CCH/*(``3"JLIBP=:YYV"'N8(`@;GHT!KLTR"_`%7KK0`;``SLK2`Z
M!5:Y&@`8ZX0``@`,N0@`&NR$`"$>5KGG@*:Y@@"CXT#RD``$[#$@OP!5PDK*
M8L'6N1H`1[D:`$KKHP`;``SLHR`Z!5;K?0`"``RY"`!*['T`(1Y6X]#RF``$
MN>=PJ,+:RF+!UKF"`*&Y!``=[-0@OP!5N1H`%KD:`!KKK0`;``SLK2`Z!5;K
M8P`"``SL8P`A'E:YZ*`QN>=@I[F"`*3C$/*@``3L0R"_`%7"&LIBP=:Y&@`8
MN1H`&NND`!L`#.RD(#H%5NN-``(`#+D(`!KLC0`A'E;CT/*H``2YYX"FPMK*
M8L'6N8(`H[D$`#WLT2"_`%6Y&@`WN1H`.NNM`!L`#.RM(#H%5NMT``(`#.QT
M`"$>5KGHH$.YYW"HN8(`H>,P\K``!.P4(+\`5<(ZRF+!UKD:`#:Y&@`ZZZ$`
M&P`,[*$@.@56ZVT``@`,N0@`.NQM`"$>5N/0\K@`!+GG8*?"VLIBP=:Y@@"D
MN00`3>S3(+\`5;D:`$BY&@!*ZZT`&P`,[*T@.@56ZX$``@`,[($`(1Y6N>B@
M%+GG@*:Y@@"CXT#RP``$[#$@OP!5PDK*8L'6N1H`1[D:`$KKHP`;``SLHR`Z
M!5;K?0`"``RY"`!*['T`(1Y6X]#RR``$N>=PJ,+:RF+!UKF"`*&Y!``=[-0@
MOP!5N1H`%KD:`!KKK0`;``SLK2`Z!5;K8P`"``SL8P`A'E:YZ*`QN>=@I[F"
M`*3C$/+0``3L0R"_`%7"&LIBP=:Y&@`8N1H`&NND`!L`#.RD(#H%5NN-``(`
M#+D(`!KLC0`A'E;CT/+8``2YYX"FPMK*8L'6N8(`H[D$`#WLT2"_`%6Y&@`W
MN1H`.NNM`!L`#.RM(#H%5NMT``(`#.QT`"$>5KGHH$.YYW"HN8(`&N,P\N``
M!.NM``(`#,(ZRF+!UNRM`"$>5KD:`#:Y!`#:[&0@OP!5N>>@I[D:`#&Y@@!*
MN00`$^.@\O``!.LV`!L`#,*JRF+!UNPV(#H%5KD:`*>Y"``QXQ#RZ``$PAK*
M8L'6N1H`&.R#(+\`5;D:`!3K2``;``SL2"`Z!5:Y"``4['$@OP!5ZT8``@`,
M[$8`(1Y6N>=`;;F"`&/K.``"``RY&@"F[#@`(1Y6N><PA+F"`!CC8/+X``3K
MAP`;``S":LIBP=;LAR`Z!5:Y&@!MN0@`BKD:`&'K%P`"``RY!`#6[!<`(1Y6
MN><0H[F"`*CL>""_`%7C@/,```3K9P`;``S"BLIBP=;L9R`Z!5:Y&@"$N0@`
M;;D:`(KLUB"_`%7KK0`;``SLK2`Z!5;K1P`"``SL1P`A'E:YZ*!XN>=`H;F"
M`*;C@/,(``3L9R"_`%7"BLIBP=:Y&@"#N1H`BNNF`!L`#.RF(#H%5NL]``(`
M#+D(`(KL/0`A'E;CH"`@``2YYS#4N1H`H[F"`'W`J@````#CH"`@`"3CT/,0
M``3LJ""_`%7"VLIBP=:Y&@#1ZQH`&P`,N1H`U^P:(#H%5NMV``(`#+D(`!WL
M=@`A'E;`&@````"YYW!CN1H`![GH$#O`"@````#`.@````#C`"`8`"3C,"`(
M`"2Y@@"&ZP$`&P`,X[#S&``$[`$@.@56PKK*8L'6ZQH``@`,N00`.^P:("$>
M5KD:`#2Y"`"1N1H`.,":`````..0(!``)+D(`#"Y&@!3P%H`````XU`@```D
MLD\`$.L1`"``#;)/`!'5!_,@$"BG=``)XT#SF``$ZV_S6``$!_3`Y?__XZD'
M!P<'Z^_P<``DIRD`@./P_V#_<<#E___AW,`Q9T4C`>,P(```).5(("@``,`_
M[\VKB>,P(`@`).5((#```,`_F+K<_N,P(!``).5,('@``,`Q$#)4=N,P(!@`
M),`_P]+A\.,P("``).-`\1``!.OO\1``!`?T!P<'!P<'ZV_P,``DN00`A.-`
M("@`!.L8``,`#;D(`!2Y!`"RP!H`````X_#_8/]QN00`H^,@(#``!+DA`$&G
MQ``$IRL``>,0L"@`).L8`!T`#+D(`!+C$+`P`"1!<+`XXQ"P>``2IX0`+Z>8
M`$`;D1F8N00`.KGRL)BY!``GN10`:;D$`$:Y&``AP.7__^0V&!E:$+!X4!"P
M>*<>`$"GA``)XT#Q$``$ZV_PT``$!_0;B;D(`*:Y%`"(N00`*\#E___SF*>.
M`#^GQ``A[!C_P`#8ZV$`!@#>[)8FOP!5IYL``=(_<`"@`+D$`"M!H*!`P.7_
M__-_IY?_]J>*_\#K%@`&`-\;@;D4`(BY!`!(N00`.KD$`"?`Y?__X_!0@+!X
MXT#Q$``$ZV_PT``$!_3KC_!``"2Y!`"SXY`P*``$XX`P,``$[!DZOSU5N10`
M,4$SL#B2@#``IQH``;D$`*+C\/]@_W&Y%``AIQX`.$$BL#BG)`!@IS@`.+GY
M$!,2$:>$``^G&O__ZS$`"`#>$C.G=`!%N18`$<80````=>L8`!@`#$(0L'!"
M@+!SZQ@`$``,0A"P<4*0L'?K&0`8``Q"$+!TN00`*^L9`!``#$(0L'7KB``(
M``Q"@+!RZYD`"``,0I"P=L#E___S!;D$`"O2`Z``L`32`Z`$L`S2`Z`(L!32
M`Z`,L!S2`Z`0L"3KC_#@``3`]/__XO+C("0``#;7_R``(`!!("$`IS;_^*?T
M_[.G.`!`N?D0$Q(1IX0`&:<:___K,0`(`-X2,Z>$``SC("0``#;7_R``(`!!
M("$`IS;_^+D6`!'&$````!"Y!``KP.7___*_US>P.+`XI_3_D-<`(``@`-<`
M(``@``<'ZW_P.``DX_#_8/]QN00`DKD$`(.Y!`!TP+```"V\P.7__]^5P!``
M`"VRN0D`L>N[``,`"KD"`+NGA``2N00`H>,0H```!+D$`$>GJP`(N00`.+D$
M`"D-X:>W__3C0/$0``3K?_#8``0']`<'!P<'!P?^!P<'!P<'Q%@``"_(P/3_
M_^`U!P<'!^MO\#``)+D$`!^G^_]@XQ#P```DP,```"Z6!P?C0/$0``3K;_#0
M``0']`<'```````"``$N`"XN```E<R\E<P`O<')O8R]S96QF+V5X90``1'EN
M84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4
M```O<')O8R\E:2\E<P!E>&4`4$%27U1%35```%!!4E]04D]'3D%-10``.@`O
M`%!%4DPU3$E"``!015),3$E"`%!%4DPU3U!4``!015),24\``%!!4E])3DE4
M24%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#
M04-(10!005)?1TQ/0D%,7T1%0E5'``!005)?1TQ/0D%,7U1-4$1)4@!005)?
M5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``,0!,
M1%],24)205)97U!!5$@`4UE35$5-```E,#)X```E<R5S)7,E<P``<&%R+0``
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES
M('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R
M871I;VXI"@``4$%42```<&%R;```+G!A<@``)7,E<V-A8VAE+25S)7,``"5S
M)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P``+W1M<```5$5-4$1)4@!4
M35``55-%4@``55-%4DY!344``!@`<&5R;```,`!005(Z.E!A8VME<CHZ5D52
M4TE/3@``,2XP-3<`56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H``"UE```M+0``979A;"`G97AE8R`O=7-R
M+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI
M;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!
M4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I
M.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F
M9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE
M(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN
M9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`]
M(#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P
M;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@
M("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW
M:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F
M:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF
M("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*
M<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E
M='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE
M+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2![
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE
M<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B
M('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD
M:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7
M:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]
M/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM
M>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N
M+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P
M87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K
M"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA
M;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY
M("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M
M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O
M('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@
M(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@
M.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@
M)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R
M;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S
M*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@
M*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@
M>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N
M(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A
M9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE
M<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D
M;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?
M<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D
M4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,[
M"GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P
M;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ
M92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N
M9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F
M(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B
M*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@
M9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?
M<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM
M>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F
M<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M
M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?
M;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@
M(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H
M<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ
M+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A
M;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N
M86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]
M"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F
M:6QE;F%M95QN(BD["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65]
M(#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN
M86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&
M2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@
M)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D
M=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N
M('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T[
M"B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@
M*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI
M('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N
M)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H
M+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R
M;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF
M;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@
M)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R
M(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D
M9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M
M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*
M<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE
M(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)
M3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@
M*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE
M.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O
M<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U
M=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE
M("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*
M?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C
M86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N
M:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A
M)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F
M('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R
M"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P
M87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E
M<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]21553
M17T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA
M=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP
M72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H
M)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G
M*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G
M*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@
M/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L
M;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF
M("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q
M<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@
M97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII
M9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!
M4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)0
M05(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.
M0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z
M.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ
M4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@
M9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S
M*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z
M:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@
M*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL
M)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3
M+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A
M<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*
M;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@
M;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*
M8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I
M;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O
M<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^
M8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E
M9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO
M861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@
M)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?
M5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO
M861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T
M(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q
M=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*
M9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A
M8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A
M9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?
M97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8
M(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D
M:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII
M9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K
M97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@
M>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D
M9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D[
M"FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI
M('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B
M*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]
M"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R
M:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE
M(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI
M;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z
M("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N
M=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E
M9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG
M="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@
M)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@
M(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N
M9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA
M;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N
M86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC
M;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG
M=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET
M:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I
M='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET
M951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II
M9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD[
M"GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X
M(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M
M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@
M)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H
M95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B
M7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I
M.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O
M9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I
M;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S
M92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@
M)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@
M9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@
M4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER
M92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M
M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@
M9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&
M2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV
M92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T
M("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II
M<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L
M9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@
M)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R
M>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@
M=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF
M:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C
M:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q
M.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!
M4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F
M("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H
M<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E
M>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT
M<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L*
M*"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T
M:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@
M*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE
M<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;
M("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M
M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E
M871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S
M96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I
M;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I
M<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97([
M"G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R
M;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E
M(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L
M('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A
M;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R
M8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA
M<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E
M<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!]
M.PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E
M;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%
M3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-
M4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D
M969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U
M<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED
M*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO
M9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]
M"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60[
M"GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[
M55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES
M>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#
M3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E
M;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@
M<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F
M:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?
M<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@
M,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I
M.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P
M;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@
M)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N
M86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H
M92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*
M)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*
M?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL
M87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@
M*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@
M/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*
M;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@
M)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E
M;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B
M)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E
M9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@
M=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@
M7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%
M?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA
M;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-
M4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I
M('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G
M;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P
M*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N
M(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2![
M"B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H
M(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!
M5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER
M(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<
M120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M
M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD
M<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E
M;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@
M)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N
M)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@
M)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I
M;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M
M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI
M;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@
M)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@
M1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?
M)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D
M14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*
M<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R
M:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]
M"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R
M97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H
M;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD
M;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q
M=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M
M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N
M('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER
M96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*
M0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*
M0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?
M7T5.1%]?"@``0T%#2$4``!__________<&5R;'AS:2YC``````````$;`SL`
M``$$````'___A*@```7`__^',````2#__X@X```!4/__B2````&@__^)Z```
M`=#__XS(```"$/__CD````),__^.\````GS__Y`0```"N/__D2@```+T__^2
M4````RS__Y*0```#3/__DO````.(__^3V````\3__Y/@```#V/__EC@```04
M__^6<```!$#__Y;````$5/__F$````2$__^8T```!*C__YD0```$S/__F@@`
M``4(__^@<```!4S__Z,(```%A/__HX````8`__^[(```!D#__[N8```&9/__
MO,````:P__^^(```!NC__[Z0```'(/__OI@```<X`````````!0``````7I2
M``%X#@$;#`^@`0<.`````!0````<__^&"````$8``````````````!0`````
M`7I2``%X#@$;#`^@`0```````$P````<__^&X````.0`1H8.APV(#(D+B@J+
M"8P(C0>.!H\%1@[``@*("L_.S<S+RLG(Q\8.H`%""P)$"L_.S<S+RLG(Q\8.
MH`%""P``````+````&S__X=X````Q`!*B@J+"8P(C0>.!H\%1@[0`@*L"L_.
MS<S+R@Z@`4(+````/````)S__X@0```"W`!*A@Z'#8@,B0N*"HL)C`B-!XX&
MCP5&#M@"`P&$"L_.S<S+RLG(Q\8.H`%""P```````#@```#<__^*L````70`
M2H8.APV(#(D+B@J+"8P(C0>.!H\%1@[@`P)$"L_.S<S+RLG(Q\8.H`%""P``
M`"P```$8__^+[````*X`6(L)C`B-!XX&CP5&#M@#`F0*S\[-S,L.H`%""P``
M`````#@```%(__^,;````2``5(<-B`R)"XH*BPF,"(T'C@:/!48.R"("M@K/
MSLW,R\K)R,<.H`%""P```````#@```&$__^-4````18`7(L)C`B-!XX&CP5&
M#L@B`I8*S\[-S,L.H`%""P)("L_.S<S+#J`!1@L``````#0```'`__^.+```
M`2(`7(@,B0N*"HL)C`B-!XX&CP5&#M""!`+@"L_.S<S+RLG(#J`!0@L`````
M'````?C__X\<````/`!,C@:/!48.P`)DS\X.H`$````X```"&/__CSP```!@
M`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.R`("4L_.S<S+RLG(Q\8.H`$`````
M```X```"5/__CV````#H`$J&#H<-B`R)"XH*BPF,"(T'C@:/!48.V$("R`K/
MSLW,R\K)R,?&#J`!0@L````0```"D/__D`P````&`````````#@```*D__^0
M`````E(`2H8.APV(#(D+B@J+"8P(C0>.!H\%1@[P(P*&"L_.S<S+RLG(Q\8.
MH`%""P```"@```+@__^2'````#8`2HL)C`B-!XX&CP5&#L`"8,_.S<S+#J`!
M````````$````PS__Y(H````3@`````````L```#(/__DF0```%Z`%J+"8P(
MC0>.!H\%1@[0`@,!*@K/SLW,RPZ@`4(+```````@```#4/__D[0```".`%J.
M!H\%1@[0`@)F"L_.#J`!0@L````@```#=/__E"`````\`$:.!H\%1@[``F8*
MS\X.H`%""P`````X```#F/__E#P```#R`%2&#H<-B`R)"XH*BPF,"(T'C@:/
M!48.X`("T`K/SLW,R\K)R,?&#J`!0@L```!````#U/__E/@```9B`%2&#H<-
MB`R)"XH*BPF,"(T'C@:/!4H.F`5(F!4#`E`*S\[-S,O*R<C'QM@.H`%""P``
M`````#0```08__^;'````I@`5(@,B0N*"HL)C`B-!XX&CP5&#M`"`P'6"L_.
MS<S+RLG(#J`!0@L`````.```!%#__YU\````=`!&B@J+"8P(C0>.!H\%1@[`
M`@)6"L_.S<S+R@Z@`4(+2L_.S<S+R@Z@`0``````/```!(S__W[@```"A`!&
MA@Z'#8@,B0N*"HL)C`B-!XX&CP5,#N@"`P'$"L_.S<S+RLG(Q\8.H`%""P``
M`````#P```3,__^=>```%YP`6(8.APV(#(D+B@J+"8P(C0>.!H\%1@[(!P,7
M=@K/SLW,R\K)R,?&#J`!0@L````````@```%#/__M-@```!R`$J.!H\%1@[`
M`@)@S\X.H`$```````!(```%,/__M2P```$H`$:&#H<-B`R)"XH*BPF,"(T'
MC@:/!60.P`("?@K/SLW,R\K)R,?&#J`!0@L"?,_.S<S+RLG(Q\8.H`$`````
M-```!7S__[8(```!7@!&B`R)"XH*BPF,"(T'C@:/!7`.P`("K@K/SLW,R\K)
MR`Z@`48+```````T```%M/__MS````!J`$:'#8@,B0N*"HL)C`B-!XX&CP5&
M#L`"`ES/SLW,R\K)R,<.H`$``````!0```7L__^W:`````(`````````````
M`!````8$__^W6`````P`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````"H0
M````````*<```````````0````````+T``````````$````````"_P``````
M```!`````````P\`````````'0````````2-``````````P````````?2```
M```````-````````8(@`````````&0```````+N(`````````!L`````````
M"``````````:````````NY``````````'``````````(``````````0`````
M```"D`````!O__[U````````!\``````````!0```````!&X``````````8`
M```````(H``````````*````````!,$`````````"P`````````8````````
M`!4````````````````````#````````O<@``````````@````````4H````
M`````!0`````````!P`````````7````````&B``````````!P```````!>P
M``````````@````````"<``````````)`````````!@`````````'@``````
M```(`````&____L`````"````0````!O___^````````%T``````;____P``
M```````"`````&____`````````6>@````!O___Y``````````X`````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````+N8````````````
M`````````````````!^V````````']8````````?]@```````"`6````````
M(#8````````@5@```````"!V````````()8````````@M@```````"#6````
M````(/8````````A%@```````"$V````````(58````````A=@```````"&6
M````````(;8````````AU@```````"'V````````(A8````````B-@``````
M`")6````````(G8````````BE@```````"*V````````(M8````````B]@``
M`````",6````````(S8````````C5@```````"-V````````(Y8````````C
MM@```````"/6````````(_8````````D%@```````"0V````````)%8`````
M```D=@```````"26````````)+8````````DU@```````"3V````````)18`
M```````E-@```````"56````````)78````````EE@```````"6V````````
M)=8````````E]@```````"86````````)C8````````F5@```````"9V````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````)H@``````````````````,`(````````8N@```````!@O```
M````````````````8;@```````!AO````````&+N````````81X```````!B
M]@``````````````````8OH```````!C````````````"E!!4BYP;0H`````
M`````````````&.<1T-#.B`H4U5312!,:6YU>"D@-RXU+C```"YS:'-T<G1A
M8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG
M;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R
M<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`
M+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N
M9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`
M````````````````````````````````````````````````````````````
M``````````````````````````````````````L````!``````````(`````
M```".`````````(X``````````\````````````````````!````````````
M```3````!P`````````"`````````D@````````"2``````````D````````
M````````````!```````````````)@````<``````````@````````)L````
M`````FP`````````(`````````````````````0``````````````#@````%
M``````````(````````"D`````````*0````````!3`````&````````````
M```(``````````@````T;___]@`````````"````````!\`````````'P```
M``````#@````!@``````````````"```````````````/@````L`````````
M`@````````B@````````"*`````````)&`````<````"``````````@`````
M````&````$8````#``````````(````````1N````````!&X````````!,$`
M```````````````````!``````````````!.;____P`````````"````````
M%GH````````6>@````````#"````!@```````````````@`````````"````
M6V____X``````````@```````!=`````````%T``````````<`````<````"
M``````````@``````````````&H````$``````````(````````7L```````
M`!>P`````````G`````&```````````````(`````````!@```!T````!```
M``````!"````````&B`````````:(`````````4H````!@```!8`````````
M"``````````8````?@````$`````````!@```````!](````````'T@`````
M````0`````````````````````0``````````````'D````!``````````8`
M```````?B````````!^(````````!P`````````````````````$````````
M`"````"$`````0`````````&````````)H@````````FB````````#H`````
M````````````````"```````````````B@````$`````````!@```````&"(
M````````8(@`````````+`````````````````````0``````````````)``
M```!``````````(```````!@N````````&"X````````02@`````````````
M```````(``````````````"8`````0`````````"````````H>````````"A
MX`````````$$````````````````````!```````````````I@````$`````
M`````@```````*+H````````HN@````````&2`````````````````````@`
M`````````````+`````.``````````,```````"[B````````*N(````````
M``@````````````````````(``````````@```"\````#P`````````#````
M````NY````````"KD``````````(````````````````````"``````````(
M````R`````8``````````P```````+N8````````JY@````````",`````<`
M``````````````@`````````$````-$````!``````````,```````"]R```
M`````*W(`````````C@````````````````````(``````````@```#6````
M`0`````````#````````P`````````"P``````````"(````````````````
M````"```````````````W`````@``````````P```````,"(````````L(@`
M````````*`````````````````````@``````````````.$````!````````
M`#```````````````````+"(`````````!@````````````````````!````
M``````$````!`````P````````````````````````````"PH`````````#J
8`````````````````````0``````````
